@@ -115,7 +115,8 @@ NormalTestLevene=FALSE
 
 #If Normality  or Homogeneity Fails
 if (NormalTestWiks==FALSE | NormalTestLevene==FALSE){    
-	DunnsTable<-dunnsTest(TempData,TreatmentVar,Response,TestDirection)
+
+	DunnsTable<-dunnsTest(AvgData,TreatmentVar,Response,TestDirection)
 	OneWayDunnetResults<-{}
 }
 
