@@ -5,6 +5,10 @@ function(Data,Treatment,Residuals){
 Data[ ,Treatment]<-as.factor(Data[ ,Treatment])
 LeveneTable<-cbind(Treatment,leveneTest(Residuals,Data[ ,Treatment])) 
 LeveneTable<-LeveneTable[-2, ]#Removes a junk row from the table 
+#Round the numbers
+LeveneTable[3]<-round(LeveneTable[3],2)
+LeveneTable[4]<-round(LeveneTable[4],4)
+
 rownames(LeveneTable)<-NULL
 return(LeveneTable)
 }
